@@ -311,7 +311,7 @@ export function shimCreateOfferLegacy(window) {
           }
         } else if (offerOptions.offerToReceiveAudio === true &&
             !audioTransceiver) {
-          this.addTransceiver('audio');
+          this.addTransceiver('audio', {direction: 'recvonly'});
         }
 
         if (typeof offerOptions.offerToReceiveVideo !== 'undefined') {
@@ -337,7 +337,7 @@ export function shimCreateOfferLegacy(window) {
           }
         } else if (offerOptions.offerToReceiveVideo === true &&
             !videoTransceiver) {
-          this.addTransceiver('video');
+          this.addTransceiver('video', {direction: 'recvonly'});
         }
       }
       return origCreateOffer.apply(this, arguments);
@@ -350,3 +350,4 @@ export function shimAudioContext(window) {
   }
   window.AudioContext = window.webkitAudioContext;
 }
+
